@@ -2,7 +2,7 @@ package Lingua::EN::Inflexion;
 use 5.010; use warnings;
 use Carp;
 
-our $VERSION = '0.000002';
+our $VERSION = '0.000003';
 
 # Import noun, verb, and adj classes...
 use Lingua::EN::Inflexion::Term;
@@ -170,7 +170,7 @@ Lingua::EN::Inflexion - Inflect English nouns, verbs, adjectives, and articles
 
 =head1 VERSION
 
-This document describes Lingua::EN::Inflexion version 0.000002
+This document describes Lingua::EN::Inflexion version 0.000003
 
 
 =head1 SYNOPSIS
@@ -305,7 +305,7 @@ calls, if the term it represents is uninflected. For example:
 Returns a string representing the corresponding inflexion of the term
 represented by the invocant. For example:
 
-    say noun('feet')->singular;    # "feet"
+    say noun('feet')->singular;    # "foot"
 
     say verb('is')->plural;        # "are"
 
@@ -335,6 +335,7 @@ any inflected form of the word. For example:
 
     $word =~ noun('cherub')->as_regex   # qr/cherubs|cherubim|cherub/i
 
+=back
 
 =head3 Regex and string coercions
 
@@ -596,7 +597,7 @@ replaces any nested markups (in angle brackets) with the appropriate
 inflexions of their contents. It then returns the inflected string.
 
 The markup notation always takes the form: C<< <Xopts:content> >>
-where C<X> is a command (either C<N> or C<V> or C<A> or <#>),
+where C<X> is a command (either C<N> or C<V> or C<A> or C<#>),
 C<opts> represents zero or more options for the command,
 and C<content> is the data on which to apply the command (normally
 a word or phrase to be inflected).
@@ -756,8 +757,6 @@ you can just use:
 
 I<Mnemonic:> C<i> for "increment" or "its intrinsic index is insufficient; increase it".
 
-=back
-
 
 =item C<d>
 
@@ -788,6 +787,7 @@ specific when the count is less than two:
 
 I<Mnemonic:> C<s> for "don't display" or "disguised definition" or "delete".
 
+=back
 
 
 =head3 C<< <N: I<contents> > >>
@@ -822,7 +822,7 @@ I<Mnemonic:> C<c> for "classical" or "cultured" or "conformatio Caesaris cascus"
 
 =item C<p>
 
-Causes the noun to inflect to the plual, regardless of the currently
+Causes the noun to inflect to the plural, regardless of the currently
 active count (i.e. regardless of the actual value specified in any
 preceding C<< <#:...> >>.
 
@@ -982,6 +982,8 @@ I simply find the classical spelling more elegant.
 
 =head1 DIAGNOSTICS
 
+=over
+
 =item C<< Missing arg to %s >>
 
 You passed an C<undef> as the single argument to C<noun()>, C<verb()>,
@@ -1216,7 +1218,7 @@ For example:
     bites         bite        bit         biting         bitten
 
 
-=head Suffix-based inflexions
+=head3 Suffix-based inflexions
 
 General suffix inflexions can be specified the same way as for
 nouns: using either an asterisk (for complete words) or a hyphen
@@ -1238,7 +1240,7 @@ For example:
     -[^e]es        -[^e]e            -[^e]ed           -[^e]ing          -[^e]ed
 
 
-=head Defective verbs
+=head3 Defective verbs
 
 Entries for defective verbs still require all five columns to be
 supplied. Use a single underscore to mark a column without supplying
